package mutil

func _ref(param string) string {
	return param + "_ref"
}

func AccountRefName() string {
	return _ref("account")
}

func ObjRefName() string {
	return _ref("obj")
}

func OrganizationRefName() string {
	return _ref("org")
}

func StatusRefName() string {
	return _ref("status")
}

func ProjectRefName() string {
	return _ref("project")
}

func InvitationRefName() string {
	return _ref("invitation")
}

func TokenName() string {
	return "token"
}
